/*
 * This file is part of dependency-check-core.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Copyright (c) 2013 Jeremy Long. All Rights Reserved.
 */
package org.owasp.dependencycheck.dependency;


import static org.junit.Assert.assertEquals;

import org.junit.Test;
import org.owasp.dependencycheck.BaseTest;

/**
 *
 * @author Jens Hausherr
 */
public class VulnerabilityTest extends BaseTest {

    /**
     * Test of equals method, of class VulnerableSoftware.
     */
    @Test
    public void testDuplicateVersions() {
        Vulnerability obj = new Vulnerability();

        obj.addVulnerableSoftware("cpe:/a:mortbay:jetty:6.1.0");
        obj.addVulnerableSoftware("cpe:/a:mortbay:jetty:6.1.1");
        obj.addVulnerableSoftware("cpe:/a:mortbay:jetty:6.1.0");

        assertEquals(2, obj.getVulnerableSoftware().size());
    }

    @Test
    public void testDpulicateVersionsWithPreviousVersion() {
        Vulnerability obj = new Vulnerability();
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.0-103%28a%29", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.0-118", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.3.132", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.12-200", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.2-127", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.9", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.10", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.11", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.12-118", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.4-143", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.0-109", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.6-156", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.4", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.3", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.10-186", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.6", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.5", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.5-146", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.8", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.7", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.2", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.0.2", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.1", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.8-177", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.0.1", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.0.0", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.7-168", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.0-103", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.11-197", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.9-178", null);
        obj.addVulnerableSoftware("cpe:/a:hp:system_management_homepage:2.1.12-200", "1");
        assertEquals(31, obj.getVulnerableSoftware().size());
    }
}
